@@ -1,23 +1,22 @@
-## Copyright (C) 2008 Søren Hauberg
-## 
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or
-## (at your option) any later version.
-## 
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-## 
-## You should have received a copy of the GNU General Public License
-## along with this program; if not, write to the Free Software
-## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+## Copyright (C) 2008 Søren Hauberg <soren@hauberg.org>
+##
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
+##
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+##
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {@var{R} =} rangefilt (@var{im})
 ## @deftypefnx{Function File} {@var{R} =} rangefilt (@var{im}, @var{domain})
-## @deftypefnx{Function File} {@var{R} =} rangefilt (@var{im}, @var{domain}, @var{padding}, ...)
+## @deftypefnx{Function File} {@var{R} =} rangefilt (@var{im}, @var{domain}, @var{padding}, @dots{})
 ## Computes the local intensity range in a neighbourhood around each pixel in
 ## an image.
 ##
@@ -45,15 +44,15 @@ function retval = rangefilt (I, domain = true (3), padding = "symmetric", vararg
   if (nargin == 0)
     error ("rangefilt: not enough input arguments");
   endif
-  
-  if (!ismatrix (I))
-    error ("rangefilt: first input must be a matrix");
+
+  if (! isnumeric (I) && ! islogical (I))
+    error ("rangefilt: I must be a numeric or logical array");
   endif
-  
-  if (!ismatrix (domain))
-    error ("rangefilt: second input argument must be a logical matrix");
+
+  if (! isnumeric (domain) && ! islogical (domain))
+    error ("rangefilt: DOMAIN must be a logical array");
   endif
-  domain = (domain > 0);
+  domain = logical (domain);
   
   ## Pad image
   pad = floor (size (domain)/2);
@@ -69,3 +68,8 @@ function retval = rangefilt (I, domain = true (3), padding = "symmetric", vararg
   retval = __spatial_filtering__ (I, domain, "range", I, 0);
 
 endfunction
+
+%!test
+%! im = rangefilt (ones (5));
+%! assert (im, zeros (5));
+
